@@ -523,6 +523,16 @@ CHECKS += [
     LinestringLocationCheck(error_code=205, column=table.the_geom, max_distance=1)
     for table in [models.Channel, models.Culvert]
 ]
+CHECKS += [
+    QueryCheck(
+        error_code=206,
+        column=models.ConnectionNode.the_geom_linestring,
+        invalid=Query(models.ConnectionNode).filter(
+            models.ConnectionNode.the_geom_linestring != None
+        ),
+        message="The 'the_geom_linestring' column of v2_connection_nodes must be NULL",
+    )
+]
 
 
 ## 025x: Connectivity
@@ -676,12 +686,6 @@ CHECKS += [
         min_value=0,
         left_inclusive=False,
     ),
-    RangeCheck(
-        error_code=312,
-        column=models.GlobalSetting.table_step_size_volume_2d,
-        min_value=0,
-        left_inclusive=False,
-    ),
     RangeCheck(
         error_code=313,
         column=models.GlobalSetting.frict_coef,
@@ -757,6 +761,15 @@ CHECKS += [
         ),
         message="an initial waterlevel type (v2_global_settings.water_level_ini_type) should be defined when using an initial waterlevel file.",
     ),
+    QueryCheck(
+        error_code=323,
+        column=models.GlobalSetting.maximum_table_step_size,
+        invalid=Query(models.GlobalSetting).filter(
+            models.GlobalSetting.maximum_table_step_size
+            < models.GlobalSetting.table_step_size,
+        ),
+        message="v2_global_settings.maximum_table_step_size should be greater than v2_global_settings.table_step_size.",
+    ),
 ]
 
 ## 04xx: Groundwater, Interflow & Infiltration
@@ -1198,6 +1211,18 @@ CHECKS += [
         "output_time_step",
     )
 ]
+CHECKS += [
+    QueryCheck(
+        error_code=1106,
+        level=CheckLevel.WARNING,
+        column=models.GlobalSetting.minimum_sim_time_step,
+        invalid=Query(models.GlobalSetting).filter(
+            models.GlobalSetting.minimum_sim_time_step
+            > (0.1 * models.GlobalSetting.sim_time_step)
+        ),
+        message="v2_global_settings.minimum_sim_time_step should be at least 10 times smaller than v2_global_settings.sim_time_step",
+    )
+]
 
 ## 111x - 114x: SIMULATION SETTINGS, numerical
 
@@ -1484,29 +1509,11 @@ class Config:
                 error_code=1,
             )
             self.checks += generate_unique_checks(model.__table__, error_code=2)
-            self.checks += generate_not_null_checks(
-                model.__table__,
-                error_code=3,
-                custom_level_map={
-                    "v2_grid_refinement.refinement_level": "warning",
-                    "v2_grid_refinement.the_geom": "warning",
-                    "v2_grid_refinement_area.refinement_level": "warning",
-                    "v2_grid_refinement_area.the_geom": "warning",
-                },
-            )
-            self.checks += generate_type_checks(
-                model.__table__,
-                error_code=4,
-                custom_level_map={
-                    "*.sewerage": "INFO",
-                    "v2_weir.external": "INFO",
-                    "v2_connection_nodes.the_geom_linestring": "info",
-                },
-            )
+            self.checks += generate_not_null_checks(model.__table__, error_code=3)
+            self.checks += generate_type_checks(model.__table__, error_code=4)
             self.checks += generate_geometry_checks(
                 model.__table__,
                 custom_level_map={
-                    "v2_connection_nodes.the_geom_linestring": "info",
                     "v2_grid_refinement.the_geom": "warning",
                     "v2_grid_refinement_area.the_geom": "warning",
                     "v2_dem_average_area.the_geom": "warning",
@@ -1517,9 +1524,6 @@ class Config:
             )
             self.checks += generate_geometry_type_checks(
                 model.__table__,
-                custom_level_map={
-                    "v2_connection_nodes.the_geom_linestring": "info",
-                },
                 error_code=6,
             )
             self.checks += generate_enum_checks(
