@@ -1,5 +1,6 @@
 from alembic import context
 from sqlalchemy import create_engine
+from threedi_modelchecker.threedi_model import constants
 from threedi_modelchecker.threedi_model.models import Base
 
 import os
@@ -30,7 +31,11 @@ def run_migrations_online():
         connectable = create_engine(get_url())
 
     with connectable.connect() as connection:
-        context.configure(connection=connection, target_metadata=target_metadata)
+        context.configure(
+            connection=connection,
+            target_metadata=target_metadata,
+            version_table=constants.VERSION_TABLE_NAME,
+        )
 
         with context.begin_transaction():
             context.run_migrations()
