@@ -207,6 +207,11 @@ class SurfaceParameter(Base):
     infiltration_decay_constant = Column(Float, nullable=False)
     infiltration_recovery_constant = Column(Float, nullable=False)
 
+    surface = relationship(
+        "Surface",
+        back_populates="surface_parameters",
+    )
+
 
 class Surface(Base):
     __tablename__ = "v2_surface"
@@ -227,6 +232,9 @@ class Surface(Base):
         ),
         nullable=True,
     )
+    surface_parameters = relationship(
+        SurfaceParameter, foreign_keys=surface_parameters_id, back_populates="surface"
+    )
 
 
 class GroundWater(Base):
@@ -413,6 +421,7 @@ class GlobalSetting(Base):
     kmax = Column(Integer, nullable=False)
     guess_dams = Column(Integer)
     table_step_size = Column(Float, nullable=False)
+    maximum_table_step_size = Column(Float)
     flooding_threshold = Column(Float, nullable=False)
     advection_1d = Column(IntegerEnum(constants.OffOrStandard), nullable=False)
     advection_2d = Column(IntegerEnum(constants.OffOrStandard), nullable=False)
@@ -437,7 +446,6 @@ class GlobalSetting(Base):
     wind_shielding_file = Column(String(255))
     use_0d_inflow = Column(IntegerEnum(constants.InflowType), nullable=False)
     table_step_size_1d = Column(Float)
-    table_step_size_volume_2d = Column(Float)
     use_2d_rain = Column(Integer, nullable=False)
     initial_groundwater_level = Column(Float)
     initial_groundwater_level_file = Column(String(255))
@@ -735,7 +743,7 @@ class Orifice(Base):
     friction_type = Column(IntegerEnum(constants.FrictionType))
     discharge_coefficient_positive = Column(Float)
     discharge_coefficient_negative = Column(Float)
-    sewerage = Column(Boolean, nullable=False)
+    sewerage = Column(Boolean)
 
     connection_node_start_id = Column(
         Integer, ForeignKey(ConnectionNode.__tablename__ + ".id"), nullable=False
